@@ -538,19 +538,21 @@ proc vtcanvas::selectionEvent {w event item x y t} {
    set my [$c canvasy $y]
    if {$my < 10} { set my 10 }
    if {$my > $d(height)-10} { set my [expr {$d(height)-10}] }
-   $c coord sellen $xc $my
    set dt [expr {abs($xtime - $d(xTimeDown))}]
    set text [invoke $w formatTimeCommand $dt]
    $c itemconf sellen -text $text
+   set he [font metrics $d(yaxisFont) -linespace]
    if {$x < 100} {
+    $c coord sellen [expr $xc+2] $my
      $c itemconf sellen -anchor sw
      set wi [font measure $d(yaxisFont) $text]
+    $c coords selbg $xc $my [expr {$xc + $wi + 4}] [expr {$my - $he}]
    } else {
+    $c coord sellen [expr $xc-2] $my
      $c itemconf sellen -anchor se
      set wi [expr -[font measure $d(yaxisFont) $text]]
+    $c coords selbg $xc $my [expr {$xc + $wi - 4}] [expr {$my - $he}]
    }
-   set he [font metrics $d(yaxisFont) -linespace]
-   $c coords selbg $xc $my [expr {$xc + $wi}] [expr {$my - $he}]
 
   }
   <ButtonRelease-1> {
